@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for mediatailor service client
 
@@ -7,16 +8,14 @@ Usage::
     import boto3
     from mypy_boto3_mediatailor import MediaTailorClient
 
-    session = boto3.Session()
-
     client: MediaTailorClient = boto3.client("mediatailor")
-    session_client: MediaTailorClient = session.client("mediatailor")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from typing import Any, Dict, List, Type
+
 from botocore.exceptions import ClientError as Boto3ClientError
+
 from mypy_boto3_mediatailor.paginator import ListPlaybackConfigurationsPaginator
 from mypy_boto3_mediatailor.type_defs import (
     AvailSuppressionTypeDef,
@@ -116,7 +115,6 @@ class MediaTailorClient:
         [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         """
 
-    @overload
     def get_paginator(
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
