@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for mediatailor service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_mediatailor import MediaTailorClient
-    from mypy_boto3_mediatailor import (
+    from mypy_boto3_mediatailor.paginator import (
         ListPlaybackConfigurationsPaginator,
     )
 
@@ -16,15 +17,15 @@ Usage::
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_mediatailor.type_defs import (
     ListPlaybackConfigurationsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("ListPlaybackConfigurationsPaginator",)
 
 
